@@ -1,12 +1,12 @@
-## version: 1.36
+## version: 1.27
 ## method: get
 ## path: /volumes
 ## code: 200
+## response: {"Volumes":[{"Name":"tardis","Driver":"local","Mountpoint":"/var/lib/docker/volumes/tardis","Labels":{"com.example.some-label":"some-value","com.example.some-other-label":"some-other-value"},"Scope":"local","Options":{"device":"tmpfs","o":"size=100m,uid=1000","type":"tmpfs"}}],"Warnings":[]}
 list(volumes = data.frame(
        name = "tardis",
        driver = "local",
        mountpoint = "/var/lib/docker/volumes/tardis",
-       created_at = "2017-07-19T12:00:26Z",
        ## TODO: status here should be list(character())
        status = I(list(list())),
        labels = I(list(c("com.example.some-label" = "some-value",
