@@ -1,4 +1,4 @@
-## version: 1.35
+## version: 1.38
 ## method: get
 ## path: /configs
 ## code: 200
@@ -15,5 +15,6 @@ data.frame(
     ## https://docs.docker.com/engine/api/v1.30/#operation/ConfigInspect
     ## the 'data' element is not returned, which is not consistent
     ## with the spec.
-    data = "VEhJUyBJUyBOT1QgQSBSRUFMIENFUlRJRklDQVRFCg=="))),
+    data = "VEhJUyBJUyBOT1QgQSBSRUFMIENFUlRJRklDQVRFCg==",
+    templating = NULL))),
   stringsAsFactors = FALSE)
